function [ compM, newcolcount ] = compress_columns( bigM, colcount )

% Hyper-Learning Code: Hyper-learn the best model of text documents
% Copyright (C) 2005  Jaime Teevan
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

% Compresses a matrix that already has all of its columns sorted so
% that the same columns are next to eachother
% by removing duplicate columns and counting the number of times it does.

% Takes an initial sorted matrix and a vector with a number 
% associated with each column in the initial matrix

% Returns a compressed matrix with only the unique columns and a vector
% of the initial associated numbers summed over individual occurrences of
% each unique column

% colcount is a number associated with each column
% that will be summed as columns are merged.

compM = [];
newcolcount = [];

% If a colcount isn't specified going in, have it be ones
% Essentially counting number of cols for each compressed col
if nargin < 2
  colcount = ones( size( bigM, 2 ), 2 );
end

current_pattern = zeros( size( bigM, 1 ), 1 );
current_pattern = current_pattern - 1;

% For each column:
for i=1:length( colcount )

  col = bigM( :, i );

  if sum( col ~= current_pattern ) > 0
    current_pattern = col;
    compM = [ compM, col ];
    newcolcount = [ newcolcount 0 ];
  end

  j = length( newcolcount );
  newcolcount( j ) = newcolcount( j ) + colcount( i );

end