function [ f, h ] = find_fh( finit, hinit, topns, Ns )

% Hyper-Learning Code: Hyper-learn the best model of text documents
% Copyright (C) 2005  Jaime Teevan
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

% Find the f and h that maximize the likelihood of observing the corpus.

% Requires several parameters:

% 1: The initial values of the parameters that are to be optimized as one vec.
%    So combine them.
x0 = [ finit' hinit' ];

% 2: Options, which tells it how to perform the minization.
%options = [];
options = optimset( 'GradObj', 'on' );
disp( 'Using gradient' );

% 3: Any constraints.  Here we leave everything unconstrained
%    except for a lower bound on some variables.  Most likely the right
%    answer: f's can't be negative, nothing else needs to be constrained.
lb_f = 0;
lb_h = -Inf;
lb = [ lb_f*ones(1,length(finit)) lb_h*ones(1,length(hinit)) ];
disp( strcat( 'Lower bound [f h]=', mat2str( [lb_f lb_h] ) ) );

% Actually do the minimization 
disp( 'Running ...' );
results = fmincon( 'wrapper', x0, [],[],[],[], lb, [],[], options, topns, Ns );

% Find the results
f = results( 1:length(results)/2 )';
h = results( length(results)/2+1:length(results) )';
