function P = get_P( f, h, phi )

% Hyper-Learning Code: Hyper-learn the best model of text documents
% Copyright (C) 2005  Jaime Teevan
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

% P is a matrix representing the probability of seeing each term
% a certain number of times.  Each column represents a term.  Each
% row represents the number of times you expect to see that term.

% Pretty much any value of phi that is too large (say, over 700) will give
% Inf since it is in the exponent, and any value of phi that is too small
% (say, under 700) will give 0 since it is in the exponent.  Just a warning.

P = repmat( f, 1, length( phi ) ) .* exp( h*phi );     % Find P un-normalized
sumP = sum( P );
sumP( sumP == 0 ) = 1;   % Hack to avoid divide by zero error ...
P = P ./ repmat( sumP, size( P, 1 ), 1 );       % Normalize

% HACK -- if phi is big_phi or -1*big_phi, that one is our
% special non-occurring term case.  (True?)
if isnan( sum( P( :, abs(phi)==1000 ) ) )
  a = zeros( length( f ), 1 );
  a( 1 ) = 1;
  P( :, abs(phi)==1000 ) = a;
end
