function [ finit, hinit ] = get_fhinit( k )

% Hyper-Learning Code: Hyper-learn the best model of text documents
% Copyright (C) 2005  Jaime Teevan
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

ONES = 0;
RAND = 1;
BERN = 2;
POIS = 3;
MULT = 4;

init_type = POIS;
LOG = 0;

finit = (0:k)';
hinit = (0:k)';

if LOG == 1
  disp( 'Using the log of the term occurrence.' );
  hinit = log( 1+hinit );
  finit = log( 1+finit );
end

if init_type == ONES
  disp( 'Initial values for f and h set to be 1.' );
  finit = ones( k+1, 1 );
  hinit = ones( k+1, 1 );
end

if init_type == RAND
  disp( 'Initial values for f and h set randomly.' );
  finit = rand( k+1, 1 );
  hinit = rand( k+1, 1 );
end

if init_type == BERN
  disp( 'Initial values for f and h set for Bernoulli distribution.' );
  finit = ones( k+1, 1 );
end

if init_type == POIS
  disp( 'Initial values for f and h set for Poisson distribution.' );
  for i = 1:k+1
    finit( i ) = 1./factorial( finit( i ) ); 
  end
end

if init_type == MULT
  disp( 'Initial values for f and h set for Multinomial distribution.' );
  l = 125.4
  for i = 1:k+1
    finit( i ) = choose( l, finit( i ) );
  end
end

function ret = choose( n, k )
  ret = prod( (n-k+1:n) ./ (1:k) );
