function [ logQ, f_g, h_g ] = get_logQ( f, h, topn, N )

% Hyper-Learning Code: Hyper-learn the best model of text documents
% Copyright (C) 2005  Jaime Teevan
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

% Since we know f and h, we can find the most likely phis
cphi = get_phi( f, h, N );

% We're operating in the log space, so Q is really log Q
% All gradients are with respect to log( Q ) as well
P = get_P( f, h, cphi );

% Zeros in probability aren't good, and when we take the log, they're
% negative infinity.  Because this makes Matlab unhappy, let's fix this
% Ugly hack -- probably better way to do this.
P( P==0 ) = 0.00000000000000000001;
logP = log(P);

logQ = sum( topn .* sum( logP.*N ) );

if isnan( logQ )
  disp( 'BAD! F and H:' );
  disp( [ f, h ] );
end

if nargout > 1
  A = get_A( N, P, topn );         % So this doesn't have to be calculated 2xs
  f_g = f_gradient( A, f );
  h_g = h_gradient( A, cphi );
end
