function [ f, h ] = learn_over_tsl( tsl, f, h, filebase )

% Hyper-Learning Code: Hyper-learn the best model of text documents
% Copyright (C) 2005  Jaime Teevan
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

% tsl: List of the training document set numbers to be run on

disp( strcat( 'Running on "', int2str(length(ql)), '" queries.' ) );

% Set k, the max number that functions f and h can deal with.
k = 5; 

% Term occurrence is capped at some value
cap = 10;

topns = {};
Ns = {};

% For each training set
for i = 1:length( tsl )

  % Load the training document set
  % Each document set is represented as the filebase plus the training set number 
  training_set_name = strcat( filebase, int2str( ql( i ) ) );
  load( training_set_name );

  % Get topn and N for this particular training set
  % Each column in N is a term occurrence pattern (e.g., a term occurs in 1 document 100 times, 
  % in 2 documents 10 times, and in 4 documents 2 times.  Otherwise, occurs 0 times)
  % topn represents the number of times each term occurrence pattern occurs in the document set.
  % This information is all that is needed for the learning.
  [ N, topn ] = get_working_N( documents, cap, k );
  
  % Store topn and N for this training set
  topns{ length(topns)+1 } = topn;
  Ns{ length(Ns)+1 } = N;

end

[ f, h ] = find_fh( f, h, topns, Ns );  % RUN!
