function [ f, h ] = main()

% Hyper-Learning Code: Hyper-learn the best model of text documents
% Copyright (C) 2005  Jaime Teevan
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

% Hyperlearns the best f and h given a number of training sets.
% A training set is a set of similar documents in the following format:
%
%   Document training set stored as a matrix
%   Each row represents a document
%   Each column represents a term
%   The value for each entry is the number of times the term occurs in the document
%
% Sets of similar documents are stored in a file named with a base and a number.
% For example, training set could be the results for TREC queries 51-150
% The set of relevant documents to TREC query 54 are located in 'training/trecquery54'
filebase = 'training/trecquery';
possible_training_sets = 51:150;

% Start by learning the best f and h for just a few training sets
% Then use those learned f and h's to learn the best f and h
% for more training sets.  Continue until you've learned over all
% possible training sets.

tsl = [];                    % Subset of training sets being learned over
[ f, h ] = get_fhinit( 5 );  % Initial values for f and h

while length( possible_training_sets ) > 0
  
  % First, add a few new training sets to the training set list
  % Want new training set list length to be 1.5 times the old length.
  new_len = floor( length( tsl )*1.5 )+1;
  for i = length( tsl )+1:new_len
    if length( possible_training_sets ) > 0
      [ val, possible_training_sets ] = choose_from_list( possible_training_sets );
      tsl = [ tsl val ];
    end
  end

  % Now, learn over expanded training set list.
  [ f, h ] = learn_over_tsl( tsl, f, h, filebase );

end