function [ value, gradient ] = wrapper( input, topns, Ns )

% Hyper-Learning Code: Hyper-learn the best model of text documents
% Copyright (C) 2005  Jaime Teevan
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

% A wrapper function for doing the minimization.
% (Actually maximizes the probability of observing our corpus.)

% Give inputs in the form [ f' h' ]
% find Q and the gradients for f and h

% Get the parameters from the input
f = input( 1:length(input)/2 )';
h = input( length(input)/2+1:length(input) )';

value = 0;
gradient = zeros( 1, length(f) + length(h) );

for i = 1:length( topns )

  [ logQ, f_g, h_g ] = get_logQ( f, h, topns{i}, Ns{i} );

  % Because it's a product over documents, and we're dealing in log space,
  % we can just sum these things.  Very convenient.
  value = value - logQ;                 % Maximizing Q, so minimize -Q
  gradient = gradient - [ f_g' h_g' ];  % Flip gradient, too

end

disp( strcat( num2str( value ), ': logQ for this iteration.' ) );